@@ -1,5 +1,5 @@
 /* GMM (C) 2018 Stephane Charette <stephanecharette@gmail.com>
- * $Id: SerialCommStub.cpp 2630 2018-10-13 06:37:31Z stephane $
+ * $Id: SerialCommStub.cpp 2637 2018-10-16 05:55:54Z stephane $
  */
 
 
@@ -26,7 +26,7 @@ void TabCanvas::close_serial_device(void)
 }
 
 
-std::string TabCanvas::read_from_device(void)
+std::string TabCanvas::read_from_device(VBytes & read_buffer)
 {
-	return get_simulated_string();
+	return get_simulated_string(read_buffer);
 }
