@@ -1,5 +1,5 @@
 /* GMM (C) 2018 Stephane Charette <stephanecharette@gmail.com>
- * $Id: TabCanvas.cpp 2694 2018-12-09 21:52:31Z stephane $
+ * $Id: TabCanvas.cpp 2695 2018-12-10 16:00:12Z stephane $
  */
 
 #include "GMM.hpp"
@@ -403,7 +403,7 @@ Image TabCanvas::draw_chart(const size_t width, const size_t height)
 	const float width_float				= static_cast<float>(width);
 	const float height_float			= static_cast<float>(height);
 	const float h_step					= 1.0f / static_cast<float>(number_of_buckets);
-	const float v_step					= 1.0f / 10.0f; // 10%, 20%, 30%, etc...
+	const float v_step					= 1.0f / 5.0f; // 20%, 40%, etc...
 	const float width_of_columns		= h_step * width_float;
 	const float one_seventh_of_column	= 1.0f * width_of_columns / 7.0f;
 	const float three_seventh_of_column	= 3.0f * width_of_columns / 7.0f;
